==> zio-aws-ec2_2.13-6.20.103.1-sources.jar: zio/aws/ec2/model/DeregisterInstanceEventNotificationAttributesRequest.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DeregisterInstanceEventNotificationAttributesRequest(
    instanceTagAttribute: zio.aws.ec2.model.DeregisterInstanceTagAttributeRequest
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DeregisterInstanceEventNotificationAttributesRequest = {
    import DeregisterInstanceEventNotificationAttributesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DeregisterInstanceEventNotificationAttributesRequest
      .builder()
      .instanceTagAttribute(instanceTagAttribute.buildAwsValue())
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.DeregisterInstanceEventNotificationAttributesRequest.ReadOnly =
    zio.aws.ec2.model.DeregisterInstanceEventNotificationAttributesRequest
      .wrap(buildAwsValue())
}
object DeregisterInstanceEventNotificationAttributesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DeregisterInstanceEventNotificationAttributesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.DeregisterInstanceEventNotificationAttributesRequest =
      zio.aws.ec2.model.DeregisterInstanceEventNotificationAttributesRequest(
        instanceTagAttribute.asEditable
      )
    def instanceTagAttribute
        : zio.aws.ec2.model.DeregisterInstanceTagAttributeRequest.ReadOnly
    def getInstanceTagAttribute: ZIO[
      Any,
      Nothing,
      zio.aws.ec2.model.DeregisterInstanceTagAttributeRequest.ReadOnly
    ] = ZIO.succeed(instanceTagAttribute)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DeregisterInstanceEventNotificationAttributesRequest
  ) extends zio.aws.ec2.model.DeregisterInstanceEventNotificationAttributesRequest.ReadOnly {
    override val instanceTagAttribute
        : zio.aws.ec2.model.DeregisterInstanceTagAttributeRequest.ReadOnly =
      zio.aws.ec2.model.DeregisterInstanceTagAttributeRequest
        .wrap(impl.instanceTagAttribute())
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DeregisterInstanceEventNotificationAttributesRequest
  ): zio.aws.ec2.model.DeregisterInstanceEventNotificationAttributesRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.13-7.21.15.7-sources.jar: zio/aws/ec2/model/DeregisterInstanceEventNotificationAttributesRequest.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DeregisterInstanceEventNotificationAttributesRequest(
    dryRun: Optional[Boolean] = Optional.Absent,
    instanceTagAttribute: zio.aws.ec2.model.DeregisterInstanceTagAttributeRequest
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DeregisterInstanceEventNotificationAttributesRequest = {
    import DeregisterInstanceEventNotificationAttributesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DeregisterInstanceEventNotificationAttributesRequest
      .builder()
      .optionallyWith(dryRun.map(value => value: java.lang.Boolean))(_.dryRun)
      .instanceTagAttribute(instanceTagAttribute.buildAwsValue())
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.DeregisterInstanceEventNotificationAttributesRequest.ReadOnly =
    zio.aws.ec2.model.DeregisterInstanceEventNotificationAttributesRequest
      .wrap(buildAwsValue())
}
object DeregisterInstanceEventNotificationAttributesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DeregisterInstanceEventNotificationAttributesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.DeregisterInstanceEventNotificationAttributesRequest =
      zio.aws.ec2.model.DeregisterInstanceEventNotificationAttributesRequest(
        dryRun.map(value => value),
        instanceTagAttribute.asEditable
      )
    def dryRun: Optional[Boolean]
    def instanceTagAttribute
        : zio.aws.ec2.model.DeregisterInstanceTagAttributeRequest.ReadOnly
    def getDryRun: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("dryRun", dryRun)
    def getInstanceTagAttribute: ZIO[
      Any,
      Nothing,
      zio.aws.ec2.model.DeregisterInstanceTagAttributeRequest.ReadOnly
    ] = ZIO.succeed(instanceTagAttribute)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DeregisterInstanceEventNotificationAttributesRequest
  ) extends zio.aws.ec2.model.DeregisterInstanceEventNotificationAttributesRequest.ReadOnly {
    override val dryRun: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.dryRun())
      .map(value => value: Boolean)
    override val instanceTagAttribute
        : zio.aws.ec2.model.DeregisterInstanceTagAttributeRequest.ReadOnly =
      zio.aws.ec2.model.DeregisterInstanceTagAttributeRequest
        .wrap(impl.instanceTagAttribute())
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DeregisterInstanceEventNotificationAttributesRequest
  ): zio.aws.ec2.model.DeregisterInstanceEventNotificationAttributesRequest.ReadOnly =
    new Wrapper(impl)
}
